%define major 50
%define libname %mklibname icu %{major}
%define develname %mklibname icu -d
%define tarballver %(echo %version|sed -e 's|\\.|_|g')

Summary:	International Components for Unicode
Name:		icu
Version:	50.1.2
%define subrel	1
Release:	%mkrel 1
Epoch:		1
License:	MIT
Group:		System/Libraries
URL:		http://www.icu-project.org/index.html
Source0:	http://download.icu-project.org/files/icu4c/%{version}/%{name}4c-%{tarballver}-src.tgz
Source1:	http://download.icu-project.org/files/icu4c/%{version}/%{name}4c-%{tarballver}-docs.zip
Patch0:		icu-50.1-disable-renaming.patch
Patch6:		icu-4.6.1-do-not-promote-ldflags.patch
Patch7:		icu-CVE-2013-2924.patch
BuildRequires:	doxygen
Requires:	%{libname} = %{epoch}:%{version}-%{release}

%description
The International Components for Unicode (ICU) libraries provide robust and
full-featured Unicode services on a wide variety of platforms. ICU supports
the most current version of the Unicode standard, and they provide support
for supplementary Unicode characters (needed for GB 18030 repertoire support).

As computing environments become more heterogeneous, software portability
becomes more important. ICU lets you produce the same results across all the
various platforms you support, without sacrificing performance. It offers
great flexibility to extend and customize the supplied services, which 
include:

  * Text: Unicode text handling, full character properties and character set
    conversions (500+ codepages)
  * Analysis: Unicode regular expressions; full Unicode sets; character, word
    and line boundaries
  * Comparison: Language sensitive collation and searching
  * Transformations: normalization, upper/lowercase, script transliterations 
    (50+ pairs)
  * Locales: Comprehensive locale data (230+) and resource bundle architecture
  * Complex Text Layout: Arabic, Hebrew, Indic and Thai
  * Time: Multi-calendar and time zone
  * Formatting and Parsing: dates, times, numbers, currencies, messages and   
    rule based

%package data
Summary:	Shared data for the International Components for Unicode
Group:		System/Libraries
BuildArch:	noarch
Conflicts:	icu-devel < 1:50.1-3

%description data
Shared data for the International Components for Unicode.

%package doc
Summary:	Documentation for the International Components for Unicode
Group:		System/Libraries
Requires:	%{name} = %{epoch}:%{version}-%{release}
BuildArch:	noarch

%description doc
Documentation for the International Components for Unicode.

%package -n %{libname}
Summary:	Libraries for the International Components for Unicode
Group:		System/Libraries
Requires:	%{name}-data = %{epoch}:%{version}

%description -n %{libname}
Libraries for the International Components for Unicode.

%package -n %{develname}
Summary:	Development files for the International Components for Unicode
Group:		Development/Other
Requires:	%{libname} = %{epoch}:%{version}-%{release}
Provides:	%{name}%{major}-devel = %{epoch}:%{version}-%{release}
Provides:	%{name}-devel = %{epoch}:%{version}-%{release}
Provides:	lib%{name}-devel = %{epoch}:%{version}-%{release}
Obsoletes:	%mklibname -d icu 36
Obsoletes:	%mklibname -d icu 34

%description -n	%{develname}
Development files and headers for the International Components for Unicode.

%prep
%setup -q -n %{name}
%patch0 -p1 -b .renaming
%patch6 -p0 -b .ldflags
%patch7 -p3 -b .CVE-2013-2924

mkdir -p docs
cd docs
unzip -q %{SOURCE1}
cd -

%build
pushd source
%configure2_5x \
	--with-library-bits=64else32 \
	--with-data-packaging=archive \
	--disable-renaming \
	--disable-samples
%make
%make doc
popd

%check
pushd source
make check
popd

%install
pushd source
%makeinstall_std
popd

%files
%{_bindir}/*
%exclude %{_bindir}/icu-config
%{_sbindir}/*

%files data
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/%{version}
%{_datadir}/%{name}/%{version}/*.dat

%files doc
%doc readme.html docs/*
%{_mandir}/man1/*
%{_mandir}/man8/*

%files -n %{libname}
%{_libdir}/*.so.%{major}*

%files -n %{develname}
%{_bindir}/icu-config
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%dir %{_includedir}/layout
%dir %{_includedir}/unicode
%{_includedir}/layout/*
%{_includedir}/unicode/*
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/%{version}
%{_libdir}/%{name}/%{version}/Makefile.inc
%{_libdir}/%{name}/%{version}/pkgdata.inc
%{_libdir}/%{name}/Makefile.inc
%{_libdir}/%{name}/current
%{_libdir}/%{name}/pkgdata.inc
%{_datadir}/%{name}/%{version}/config
%{_datadir}/%{name}/%{version}/install-sh
%{_datadir}/%{name}/%{version}/license.html
%{_datadir}/%{name}/%{version}/mkinstalldirs


%changelog
* Wed Oct 16 2013 luigiwalser <luigiwalser> 1:50.1.2-1.1.mga3
+ Revision: 501728
- add upstream patch to fix CVE-2013-2924

* Wed Jan 30 2013 luigiwalser <luigiwalser> 1:50.1.2-1.mga3
+ Revision: 393609
- 50.1.2

* Sat Jan 12 2013 umeabot <umeabot> 1:50.1.1-2.mga3
+ Revision: 354220
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 22 2012 fwang <fwang> 1:50.1.1-1.mga3
+ Revision: 333784
- new version 50.1.1

* Sat Nov 10 2012 fwang <fwang> 1:50.1-5.mga3
+ Revision: 316795
- add upstream real fix

* Fri Nov 09 2012 fwang <fwang> 1:50.1-4.mga3
+ Revision: 316695
- add patch from upstream bug#9717 to disable cxx11

* Thu Nov 08 2012 fwang <fwang> 1:50.1-3.mga3
+ Revision: 316345
- split out data file
- disable renaming form uconfig as suggested

* Thu Nov 08 2012 fwang <fwang> 1:50.1-2.mga3
+ Revision: 316341
- update build switch as sugggested by upstream

* Tue Nov 06 2012 fwang <fwang> 1:50.1-1.mga3
+ Revision: 314716
- new version 50.1

* Fri Jun 08 2012 fwang <fwang> 1:49.1.2-1.mga3
+ Revision: 257499
- new version 49.1.2

* Tue May 29 2012 fwang <fwang> 1:49.1.1-1.mga3
+ Revision: 248933
- new version 49.1.1

* Fri Dec 30 2011 anssi <anssi> 1:4.8.1.1-2.mga2
+ Revision: 188944
- fix CVE-2011-4599 (buffer overflow, patch from rhel6, via Mandriva)

* Sun Nov 27 2011 fwang <fwang> 1:4.8.1.1-1.mga2
+ Revision: 172772
- new version 4.8.1.1

* Fri Sep 02 2011 tv <tv> 1:4.8.1-2.mga2
+ Revision: 137820
- make the huge doc subpackage be noarch

  + fwang <fwang>
    - new version 4.8.1

* Mon Jun 20 2011 fwang <fwang> 1:4.8-1.mga2
+ Revision: 110250
- sync patches from mandriva
- new version 4.8

  + rtp <rtp>
    - backport fix from upstream ticket 7664 (bad asm syntax)

* Sun Jan 09 2011 blino <blino> 1:4.4.2-2.mga1
+ Revision: 1505
- remove old ldconfig scriptlets
- imported package icu


* Mon Oct 04 2010 Funda Wang <fwang@mandriva.org> 1:4.4.2-1mdv2011.0
+ Revision: 582874
- new version 4.4.2

* Sat Jul 31 2010 Funda Wang <fwang@mandriva.org> 1:4.4.1-1mdv2011.0
+ Revision: 563953
- do not use strict alias patch but use cflags, upstream does not like the patch
- add upstream patch to deal with buffer overflow problem
- revert to 4.4.1 stable

  + Matthew Dawkins <mattydaw@mandriva.org>
    - new version 4.5.1
      patch applied upstream

* Sun Mar 21 2010 Funda Wang <fwang@mandriva.org> 1:4.4-2mdv2010.1
+ Revision: 526037
- install libicutest

* Sat Mar 20 2010 Emmanuel Andry <eandry@mandriva.org> 1:4.4-1mdv2010.1
+ Revision: 525429
- New version 4.4
- New major 44
- rediff p4

  + Funda Wang <fwang@mandriva.org>
    - build 64 bits at first

* Mon Jan 11 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 1:4.2.1-2mdv2010.1
+ Revision: 489818
- Patch4: fix build
- really use 4.2.1 tarballs

* Sat Jul 25 2009 Frederik Himpe <fhimpe@mandriva.org> 1:4.2.1-1mdv2010.0
+ Revision: 399844
- update to new version 4.2.1

* Sun May 31 2009 Funda Wang <fwang@mandriva.org> 1:4.2-2mdv2010.0
+ Revision: 381588
- stil use fedora's icu-config

* Sun May 31 2009 Funda Wang <fwang@mandriva.org> 1:4.2-1mdv2010.0
+ Revision: 381575
- New version 4.2

  + Christophe Fergeau <cfergeau@mandriva.com>
    - fix compilation with gcc 4.4

* Tue Jan 20 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1:4.0.1-1mdv2009.1
+ Revision: 331791
- update to new version 4.0.1

* Sun Dec 21 2008 Oden Eriksson <oeriksson@mandriva.com> 1:4.0-3mdv2009.1
+ Revision: 316951
- fix build with -Werror=format-security (P3)
- rebuild

* Wed Jul 16 2008 Funda Wang <fwang@mandriva.org> 1:4.0-2mdv2009.0
+ Revision: 236515
- switch fedora's icu-config for the package's own icu-config breaks too much

* Fri Jul 04 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1:4.0-1mdv2009.0
+ Revision: 231685
- enable epoch :(
- update to new version 4.0 (looks like the versioning has been broken, epoch needed ?)
- fix descriptions
- Patch1: enable build with strict-aliasing
- Patch2: add icu.pc
- add buildrequires on doxygen
- enable checks
- fix file list

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Fri May 30 2008 Funda Wang <fwang@mandriva.org> 4.0.d01-1mdv2009.0
+ Revision: 213349
- New version 4.0.d01

* Sat Jan 26 2008 Funda Wang <fwang@mandriva.org> 3.8.1-2mdv2008.1
+ Revision: 158374
- fix CVE 2007-4770 and 4771

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Dec 14 2007 Funda Wang <fwang@mandriva.org> 3.8.1-1mdv2008.1
+ Revision: 120061
- New version 3.8.1

* Tue Dec 11 2007 Marcelo Ricardo Leitner <mrl@mandriva.com> 3.8-2mdv2008.1
+ Revision: 117322
- Added patch setBreakType, which makes that method public, as OOo requires it
  to be.

* Sat Oct 27 2007 Funda Wang <fwang@mandriva.org> 3.8-1mdv2008.1
+ Revision: 102667
- New version 3.8
- New major ( 36 -> 38 )

* Sat Sep 01 2007 Pascal Terjan <pterjan@mandriva.org> 3.6-4mdv2008.0
+ Revision: 77367
- Move icu-config to -devel package and fix it on x86_64

* Sun Jun 24 2007 Funda Wang <fwang@mandriva.org> 3.6-3mdv2008.0
+ Revision: 43594
- adopt to new devel package policy again

* Thu Jun 21 2007 Funda Wang <fwang@mandriva.org> 3.6-2mdv2008.0
+ Revision: 42306
- Really use correct tarball

* Wed Jun 20 2007 Funda Wang <fwang@mandriva.org> 3.6-1mdv2008.0
+ Revision: 41947
- correct tarball name
  remove invalid directory
  adopt to new develname
- New version
- Import icu



* Tue Jan  3 2006 Gtz Waschk <waschk@mandriva.org> 3.4-2mdk
- drop devel package obsoletes
- drop prereq
- make the devel package installable

* Tue Jan 03 2006 Oden Eriksson <oeriksson@mandriva.com> 3.4-1mdk
- 3.4
- drop the upstream patch (P0)
- fix deps
- make it rpmbuildupdate aware

* Tue May 10 2005 Arnaud de Lorbeau <devel@mandriva.com> 3.2-2mdk
- Provides icu32-devel

* Tue May 10 2005 Arnaud de Lorbeau <devel@mandriva.com> 3.2-1mdk
- 3.2

* Mon Jun  7 2004 Gtz Waschk <waschk@linux-mandrake.com> 2.8.d01-3mdk
- rebuild

* Fri Jun 04 2004 Marcel Pol <mpol@mandrake.org> 2.8.d01-2mdk
- rebuild

* Wed Dec 17 2003 Marcel Pol <mpol@mandrake.org> 2.8.d01-1mdk
- major is 28
- From Quel Qun <kelk1@hotmail.com>
    - Mandrake package.
